************
Installation
************


Installing dlnpyutils
=====================

The easiest way to install |dlnpyutils| is using pip:

.. code-block:: bash

    pip install dlnpyutils

To get the lastest version:


    pip install git+https://github.com/dnidever/dlnpyutils

    
Dependencies
============

Here are the required packages.  Most of them can be pip installed.

- numpy
- scipy
- astropy
- matplotlib
